<img style="float: left;"  src="https://github.com/amengede/pykrasue/blob/main/logo.jpg" width = 100 display="inline"></img>
# Krasue
Krasue is a high performance alternative to pygame and arcade. Pygame is a wrapper around SDL, which claims to be hardware accelerated, but either isn't or isn't fast enough. Arcade claims to be faster than pygame due to its OpenGL backend, but takes far too long to load and is measurably slower. A simple OpenGL program should outperform both of them, hence Krasue.
### Instalation
```
pip install PyKrasue
```
### Reference
All source code is documented in this repo, also check out the examples.